@@ -23,7 +23,7 @@ TODOs:
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch"
-__version__ = "1.2.2"
+__version__ = "1.2.3"
 
 
 def _autotype(var):
@@ -196,13 +196,13 @@ def readSLHA(spcstr, ignorenobr=False):
         ## Handle BLOCK/DECAY start lines
         if line.upper().startswith("BLOCK"):
             #print line
-            match = re.match(r"BLOCK\s+(\w+)(\s+Q=\s*.+)?", line.upper())
+            match = re.match(r"BLOCK\s+(\w+)(\s+Q\s*=\s*.+)?", line.upper())
             if not match:
                 continue
             blockname = match.group(1)
             qstr = match.group(2)
             if qstr is not None:
-                qstr = qstr[2:].strip()
+                qstr = qstr[qstr.find("=")+1:].strip()
             currentblock = blockname
             currentdecay = None
             blocks[blockname] = Block(blockname, q=qstr)
@@ -293,7 +293,7 @@ def writeSLHA(blocks, decays, ignorenobr=False):
     for bname, b in sorted(blocks.iteritems()):
         namestr = b.name
         if b.q is not None:
-            namestr += " Q= %e" % b.q
+            namestr += " Q= %e" % float(b.q)
         out += "BLOCK %s\n" % namestr
         for s in dict_hier_strs(b.entries):
             out += sep + s + "\n"
@@ -337,6 +337,10 @@ _HERWIGID2PDGID[129] = -13
 _HERWIGID2PDGID[130] = -14
 _HERWIGID2PDGID[131] = -15
 _HERWIGID2PDGID[132] = -16
+_HERWIGID2PDGID[198] =  24 # W+
+_HERWIGID2PDGID[199] = -24 # W-
+_HERWIGID2PDGID[200] =  23 # Z0
+_HERWIGID2PDGID[201] =  25 ## SM HIGGS
 _HERWIGID2PDGID[203] =  25 ## HIGGSL0 (== PDG standard in this direction)
 _HERWIGID2PDGID[204] =  35 ## HIGGSH0
 _HERWIGID2PDGID[205] =  36 ## HIGGSA0
@@ -561,7 +565,10 @@ _PDGID2HERWIGID[     -13] = 129
 _PDGID2HERWIGID[     -14] = 130
 _PDGID2HERWIGID[     -15] = 131
 _PDGID2HERWIGID[     -16] = 132
-_PDGID2HERWIGID[      25] = 203 ## HIGGSL0 (added for PDG standard -> HERWIG IDHW)
+_PDGID2HERWIGID[      24] = 198 ## W+
+_PDGID2HERWIGID[     -24] = 199 ## W-
+_PDGID2HERWIGID[      23] = 200 ## Z
+_PDGID2HERWIGID[      25] = 203 ## HIGGSL0 (added for PDG standard -> HERWIG IDHW) # TODO: should be 201?
 _PDGID2HERWIGID[      26] = 203 ## HIGGSL0
 _PDGID2HERWIGID[      35] = 204 ## HIGGSH0
 _PDGID2HERWIGID[      36] = 205 ## HIGGSA0
